==> hsfs-2.3.3.tar.gz: hsfs-2.3.3/hsfs/constructor/prepared_statement_parameter.py <==
#
#  Copyright 2021. Logical Clocks AB
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
#

import humps
import json

from hsfs import util


class PreparedStatementParameter:
    def __init__(self, name=None, index=None, type=None, href=None):
        self._name = name
        self._index = index

    @classmethod
    def from_response_json(cls, json_dict):
        json_decamelized = humps.decamelize(json_dict)
        return cls(**json_decamelized)

    def update_from_response_json(self, json_dict):
        json_decamelized = humps.decamelize(json_dict)
        self.__init__(**json_decamelized)
        return self

    def json(self):
        return json.dumps(self, cls=util.FeatureStoreEncoder)

    def to_dict(self):
        return {"name": self._name, "index": self._index}

    @property
    def name(self):
        return self._name

    @property
    def index(self):
        return self._index

    @name.setter
    def name(self, name):
        self._name = name

    @index.setter
    def prepared_statement_index(self, index):
        self._index = index

==> hsfs-3.7.0rc4.tar.gz: hsfs-3.7.0rc4/hsfs/constructor/prepared_statement_parameter.py <==
#
#  Copyright 2021. Logical Clocks AB
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
#

import humps
import json

from hsfs import util


class PreparedStatementParameter:
    def __init__(self, name=None, index=None, type=None, href=None, **kwargs):
        self._name = name
        self._index = index

    @classmethod
    def from_response_json(cls, json_dict):
        json_decamelized = humps.decamelize(json_dict)
        return cls(**json_decamelized)

    def update_from_response_json(self, json_dict):
        json_decamelized = humps.decamelize(json_dict)
        self.__init__(**json_decamelized)
        return self

    def json(self):
        return json.dumps(self, cls=util.FeatureStoreEncoder)

    def to_dict(self):
        return {"name": self._name, "index": self._index}

    @property
    def name(self):
        return self._name

    @property
    def index(self):
        return self._index

    @name.setter
    def name(self, name):
        self._name = name

    @index.setter
    def prepared_statement_index(self, index):
        self._index = index
